#!/usr/bin/perl -w

=header
AUTOR: 
CRIADO EM: 

REVISÕES:
--------------------------------------------------------------
<versão> <Data da Revisão>, <autor da revisao>
    - <Descrição das modificações>

=cut

# Linhas obrigatórias
use strict;
use warnings;
use English;
use Switch;
use Nagios::Plugin;
use File::Basename;
use Data::Dumper;
use vars qw ($np);

# Editar as constantes conforme necessidade
use constant{
    TRUE => 1,
    FALSE => 0,
    VERSION => '1.0',
    START_INTERVAL_DEFAULT => 0,
    END_INTERVAL_DEFAULT => 100,
};

# Fim das linhas obrigatórias

################################################################################
# Exibe o manual do software
################################################################################

sub getGuideLine {

    print <<EOF;

------------------------------------------
Manual de exemplo.
------------------------------------------

Descrição do plugin:
    Este plugin monitora o valor gerado randomicamente pelo sistema.

Instalação:
    Passos para instalação

Dependências:
    <Listar todas>
    perl module English
    Instalação: yum install "perl(English)" -y

    perl module Switch;
    Instalação: yum install "perl(Switch)" -y

    perl module Nagios::Plugin;
    Instalação: yum install "perl(Nagios::Plugin)" -y

Funcionamento:
    O plugin recebe do usuário um intervalo no qual deve gerar um numero de forma
    randômica e caso o valor seja maior que o threshold ele alarma.

Exemplos de execução e retorno do comando:
    <Listar todos possíveis>

    ./check_example -s 1 -e 15
    OK: Numero gerado 10

    ./check_example -s 1 -e 15 --perfdata
    OK: Numero gerado 15 | num=15;;;;

    ./check_example -s 1 -e 15 -w 10 -c 11
    CRITICAL: Numero gerado 15 | num=15;10;11;;

    ./check_example -s 1 -e 15 -w 10 -c 20
    WARNING: Numero gerado 15 | num=15;10;20;;

    ./check_example -s 20 -e 15
    UNKNOWN: Intervalo invalido

EOF
    exit (OK);

}

################################################################################
# Seta os atributos da variável global $np
################################################################################

sub setNagios() {

    # Constructor
    $np = Nagios::Plugin->new(
        url => "www.opservices.com.br/suporte",
        shortname => "\r", # Elimina o shortname
        version => VERSION,
        license => "Developed by:\n\tOpServices\n"
            . "Author: \n\tDaniel Ortiz - daniel.ortiz\@opservices.com\n",
        usage => "Usage:\n\t%s -s <start_number> -e <end_number>\n"
            . " \t\t [-w <warning>] [-c <critical>]",
    );

    $np->add_arg(
        spec => "start|s=i",
        required => TRUE,
        help => ["Initial interval number"],
        default => START_INTERVAL_DEFAULT
    );

    $np->add_arg(
        spec => "end|e=i",
        required => TRUE,
        help => ["End interval number"],
        default => END_INTERVAL_DEFAULT
    );

    $np->add_arg(
        spec => "warning|w=i",
        help => ["Warning value"]
    );

    $np->add_arg(
        spec => "critical|c=i",
        help => ["Critical value"]
    );

    $np->add_arg(
        spec => "perfdata",
        help => ["Show perfdata"]
    );

    $np->add_arg(
        spec => "man",
        help => ["Show guideline"]
    );

    $np->getopts;

}

################################################################################
# Gera um numero randômico entre dois valores passado por parâmetro.
# O numero gerado segue o seguinte padrão: x >= start e x <= end
# @link http://www.justskins.com/forums/random-number-between-x-57761.html
# @param $start Valor inicial do intervalo
# @param $end Valor final do intervalo
# @return $randomNumber Numero randômico gerado.
################################################################################


sub getRandomNumber($$) {
    my ($start, $end) = @ARG;

    $np->nagios_die("Intervalo inválido") if ($start > $end);

    my $randomNumber = int( rand( $end - $start + 1 ) ) + $start;

    print "Debug: Numero Gerado $randomNumber\n" if ($np->opts->verbose == 1);


    if ($np->opts->verbose > 1) {
		print "Debug: Start interval $start\n";
		print "Debug: End interval $end\n";
	    print "Debug: Numero Gerado $randomNumber\n";
	}

    return $randomNumber;
}

################################################################################
# Rotina principal do programa
################################################################################

sub main() {
    setNagios();

    getGuideLine() if ($np->opts->man);

    my $randomNumber = getRandomNumber($np->opts->start, $np->opts->end);

    $np->add_perfdata(
        label => "num",
        value => $randomNumber,
        warning => $np->opts->warning,
        critical => $np->opts->critical,
        min => 0,
        max => ""

    ) if ( $np->opts->perfdata or ($np->opts->warning and $np->opts->critical) );

    $np->nagios_exit(
        return_code => $np->check_threshold($randomNumber),
        message => "Numero gerado $randomNumber"
    );
}

&main;

# vim: set smartindent tabstop=4 shiftwidth=4 softtabstop=4 expandtab[ENTER] #
